#!/bin/sh

if ! which realpath > /dev/null ; then
    echo "Please install the realpath program." 1>&2
    exit 1
fi

THISDIR=`dirname "$0"`
DIRNAME=`realpath "$THISDIR/.."`
PROGNAME=`basename "$0"`

if [ "$1" = '--help' ] || [ ! "$1" ] ; then
    cat 1>&2 <<EOF
Usage: $PROGNAME <platform> | <build directory>

Update platform-specific files for the indicated platform type. If a build
directory is specified, try and obtain a configured platform type and use that
to update the files.

This program updates files in the distribution. They must then be installed
using the install program:

$THISDIR/install.sh
EOF
    exit 1
fi

# Check for a build directory and obtain a platform type.

if [ -e "$1" ] && [ -e "$1/.config.platform" ] ; then
    PLATFORM=`grep -e 'CONFIG_PLATFORM_TYPE=' "$1/.config.platform" | sed 's/^.*"\(.*\)".*$/\1/'`

# Check for a recognised platform type.

elif grep -q -F -e "$1" "$DIRNAME/conf/landfall-examples/platforms.txt" ; then
    PLATFORM="$1"

# Show an error for anything else.

else
    cat 1>&2 <<EOF
Platform not recognised: $1
EOF
    exit 1
fi

# Panel configuration file in this distribution.

PANELCONF="$DIRNAME/conf/landfall-examples/mips-jz4740-panel.txt"

# Determine the required value of the panel configuration.

PANELLIB="rom/libpanel_$PLATFORM.so"

# Write it to the configuration file.

echo -n "$PANELLIB" > "$PANELCONF"
